﻿# Author:            weixeflo@fawcs.info
# Date:              20160325
# Description:       Script sends timestamp or ack-state back to queried item


param (
  [Parameter(Mandatory=$true,Position=1)]
  [string]$vCenter="",
   [Parameter(Mandatory=$true,Position=2)]
  [string]$user="",
   [Parameter(Mandatory=$true,Position=3)]
  [string]$password="",
  [Parameter(Mandatory=$true,Position=4)]
  [string]$item="none",
  [Parameter(Mandatory=$true,Position=5)]
  [string]$itemType="timestamp"
)

if( $item -eq "none")
{
    echo "ERROR: Item name not set";
    exit
}

#functions
Function convertSeverity {
    param(
        [Parameter(Mandatory=$true)]
        [string]$severityString
    )
    $ret="0"
    switch ($severityString)
    {
        green { $ret="0"; break }
        grün { $ret="0"; break }
        yellow { $ret="1"; break }
        gelb { $ret="1"; break }
        red { $ret="2"; break }
        rot { $ret="2"; break }
        gray { $ret="3"; break }
        grau { $ret="3"; break }

    }

    return $ret
}

Function ReplaceMutations {

    param (
       [string]$Text 
    )
 
    # create Table with replace map
    $characterMap = @{}
    $characterMap.([Int][Char]'ä') = "ae"
    $characterMap.([Int][Char]'ö') = "oe"
    $characterMap.([Int][Char]'ü') = "ue"
    $characterMap.([Int][Char]'ß') = "ss"
    $characterMap.([Int][Char]'Ä') = "Ae"
    $characterMap.([Int][Char]'Ü') = "Ue"
    $characterMap.([Int][Char]'Ö') = "Oe"
    $characterMap.([Int][Char]'á') = "_"
    $characterMap.([Int][Char]"`n") = " "
    
    # Replace chars
    ForEach ($key in $characterMap.Keys) {
        $Text = $Text -creplace ([Char]$key),$characterMap[$key] 
    }
 
     # return result
     $Text
}


Add-PSSnapin VMWare.VimAutomation.Core
#VAR definitions
$unixtime=Get-Date -Date "01/01/1970"
$output=""



$connect=Connect-VIServer $vCenter -User $user -Password $password

if($itemType -eq "timestamp")
{ # RETURN TIMESTAMP
Foreach ($alarm in (Get-Folder -NoRecursion).ExtensionData.TriggeredAlarmState) {
        $AlarmID = $($alarm.Key)
        if( $AlarmID -eq $item)
        {
            #use timestamp for output
            $AlarmTime = $($alarm.Time)
            $output=$((New-TimeSpan -Start $unixtime -End $AlarmTime.DateTime ).TotalSeconds)
        }

    }
}
if($itemType -eq "ackState")
{ # RETURN ACK-State
    Foreach ($alarm in (Get-Folder -NoRecursion).ExtensionData.TriggeredAlarmState) {
        $AlarmID = $($alarm.Key)
        if( $AlarmID -eq $item)
        {
            #use Acknowledge-state for output
            if( $($alarm.Acknowledged)) 
            {
                $output="1"
            } else {
                $output="0"
            }
        }
    }
}
if($itemType -eq "severity")
{ # RETURN ACK-State
    Foreach ($alarm in (Get-Folder -NoRecursion).ExtensionData.TriggeredAlarmState) {
        $AlarmID = $($alarm.Key)
        if( $AlarmID -eq $item)
        {
            #use Acknowledge-state for output
            $output = convertSeverity($($alarm.OverallStatus))
        }
    }
}

if($output -eq "" )
{
    echo "ERROR: Output is not defined!"
} else {
    echo $output
}




